<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ZoomToSelection</name>
    <message>
        <location filename="../ZoomToSelection.js" line="+31"/>
        <source>No selection found.</source>
        <translation>Není nic vybráno.</translation>
    </message>
    <message>
        <location filename="../ZoomToSelectionInit.js" line="+2"/>
        <source>Zoom to &amp;Selection</source>
        <translation>Přiblížit na &amp;výběr</translation>
    </message>
</context>
</TS>
